==> birdtray_1.8.0+ds.orig.tar.xz: birdtray-1.8.0/src/translations/installer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Italian</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Una notifica gratuita sulla barra delle applicazioni per la nuova posta di Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integrazione con Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Seleziona come integrare il programma in Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Avvio Automatico</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Avvia automaticamente ${PRODUCT_NAME} dopo l'accesso.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Controllo Aggiornamento Automatico</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Cerca automaticamente aggiornamenti di ${PRODUCT_NAME} all'avvio.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Program Group Entry</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Crea un gruppo di programmi ${PRODUCT_NAME} in Menu Start > Programmi.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Voce Desktop</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Crea un'icona ${PRODUCT_NAME} sul desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Avvia voce di menu</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Crea un'icona ${PRODUCT_NAME} nel menu Start.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Seleziona traduzioni per ${PRODUCT_NAME}. ${PRODUCT_NAME} sceglierà una traduzione in base alla lingua del sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Impostazioni Utente</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Le impostazioni e la configurazione effettuate all'interno di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Accordo di Licenza</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Inizia ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Fai clic su Disinstalla per iniziare il processo.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Disinstallazione della versione precedente di ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Disinstallazione non riuscita della vecchia installazione ${PRODUCT_NAME}! Continuando cancellerai TUTTO in $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Errore durante l'esecuzione del programma di disinstallazione.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} è attualmente in esecuzione. Premi OK per interrompere ${PRODUCT_NAME} per continuare con l'installazione.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Processo di chiusura ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Impossibile chiudere ${PRODUCT_NAME}. Riprova o esci da ${PRODUCT_NAME} manualmente per continuare con l'installazione.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} è attualmente in esecuzione. Premi OK per interrompere ${PRODUCT_NAME} per continuare con la disinstallazione.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Impossibile chiudere ${PRODUCT_NAME}. Riprova o esci da ${PRODUCT_NAME} manualmente per continuare con la disinstallazione.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>L'impostazione di ${PRODUCT_NAME} è già in esecuzione. $\r$\nSi prega di chiudere tutte le istanze e fare clic su Riprova per continuare o Annulla per uscire.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>La disinstallazione di ${PRODUCT_NAME} è già in esecuzione. $\r$\nChiudi tutte le istanze e fai clic su Riprova per continuare o Annulla per uscire.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Il percorso di installazione non deve contenere $\r$\n ${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>TIl percorso di installazione contiene una versione ${PRODUCT_NAME} precedentemente installata, che verrà sostituita.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Il percorso di installazione non è vuoto, ma non sembra contenere un'installazione precedente di ${PRODUCT_NAME}. Il contenuto verrà sovrascritto.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (solo utente corrente)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} non può essere installato completamente.$\r$\n\ Per favore, riavvia Windows ed esegui di nuovo il programma di installazione.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} non può essere completamente installato.$\r$\n\Riavvia Windows ed esegui nuovamente il programma di installazione.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} non può essere disinstallato completamente.$\r$\nSi prega di riavviare Windows ed eseguire nuovamente il programma di disinstallazione.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Errore durante l'eliminazione del file:$\r$\n$\r$\n$0$\r$\n$\r$\nFai clic su Riprova per riprovare oppure$\r$\nAnnulla per interrompere la disinstallazione.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Errore durante l'eliminazione del file $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Stai per installare la versione a 32 bit di ${PRODUCT_NAME} sul tuo Windows a 64 bit. È disponibile per il download una versione a 64 bit di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Questo programma di installazione contiene la versione a 64 bit di ${PRODUCT_NAME}. Il computer esegue una versione a 32 bit di Windows, che non può eseguire programmi a 64 bit. Scarica il programma di installazione a 32 bit di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Questo programma richiede almeno Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>La disinstallazione di ${PRODUCT_NAME} è stata interrotta. Per favore riprova più tardi.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} settings</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Opening $0 in default browser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Unable to find Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>The following required component was not found on this computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDo you want to download the installer for the component?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>The required component was successfully detected on your computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} will not be able to run.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} will not be able to start because a required component is missing.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Olandese</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
</context>
</TS>

==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Italian</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Una notifica gratuita sulla barra delle applicazioni per la nuova posta di Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integrazione con Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Seleziona come integrare il programma in Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Avvio Automatico</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Avvia automaticamente ${PRODUCT_NAME} dopo l'accesso.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Controllo Aggiornamento Automatico</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Cerca automaticamente aggiornamenti di ${PRODUCT_NAME} all'avvio.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Program Group Entry</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Crea un gruppo di programmi ${PRODUCT_NAME} in Menu Start > Programmi.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Voce Desktop</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Crea un'icona ${PRODUCT_NAME} sul desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Avvia voce di menu</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Crea un'icona ${PRODUCT_NAME} nel menu Start.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Seleziona traduzioni per ${PRODUCT_NAME}. ${PRODUCT_NAME} sceglierà una traduzione in base alla lingua del sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Impostazioni Utente</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Le impostazioni e la configurazione effettuate all'interno di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Accordo di Licenza</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Inizia ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Fai clic su Disinstalla per iniziare il processo.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Disinstallazione della versione precedente di ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Disinstallazione non riuscita della vecchia installazione ${PRODUCT_NAME}! Continuando cancellerai TUTTO in $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Errore durante l'esecuzione del programma di disinstallazione.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} è attualmente in esecuzione. Premi OK per interrompere ${PRODUCT_NAME} per continuare con l'installazione.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Processo di chiusura ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Impossibile chiudere ${PRODUCT_NAME}. Riprova o esci da ${PRODUCT_NAME} manualmente per continuare con l'installazione.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} è attualmente in esecuzione. Premi OK per interrompere ${PRODUCT_NAME} per continuare con la disinstallazione.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Impossibile chiudere ${PRODUCT_NAME}. Riprova o esci da ${PRODUCT_NAME} manualmente per continuare con la disinstallazione.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>L'impostazione di ${PRODUCT_NAME} è già in esecuzione. $\r$\nSi prega di chiudere tutte le istanze e fare clic su Riprova per continuare o Annulla per uscire.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>La disinstallazione di ${PRODUCT_NAME} è già in esecuzione. $\r$\nChiudi tutte le istanze e fai clic su Riprova per continuare o Annulla per uscire.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Il percorso di installazione non deve contenere $\r$\n ${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>TIl percorso di installazione contiene una versione ${PRODUCT_NAME} precedentemente installata, che verrà sostituita.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Il percorso di installazione non è vuoto, ma non sembra contenere un'installazione precedente di ${PRODUCT_NAME}. Il contenuto verrà sovrascritto.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (solo utente corrente)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} non può essere installato completamente.$\r$\n\ Per favore, riavvia Windows ed esegui di nuovo il programma di installazione.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} non può essere completamente installato.$\r$\n\Riavvia Windows ed esegui nuovamente il programma di installazione.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} non può essere disinstallato completamente.$\r$\nSi prega di riavviare Windows ed eseguire nuovamente il programma di disinstallazione.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Errore durante l'eliminazione del file:$\r$\n$\r$\n$0$\r$\n$\r$\nFai clic su Riprova per riprovare oppure$\r$\nAnnulla per interrompere la disinstallazione.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Errore durante l'eliminazione del file $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Stai per installare la versione a 32 bit di ${PRODUCT_NAME} sul tuo Windows a 64 bit. È disponibile per il download una versione a 64 bit di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Questo programma di installazione contiene la versione a 64 bit di ${PRODUCT_NAME}. Il computer esegue una versione a 32 bit di Windows, che non può eseguire programmi a 64 bit. Scarica il programma di installazione a 32 bit di ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Questo programma richiede almeno Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>La disinstallazione di ${PRODUCT_NAME} è stata interrotta. Per favore riprova più tardi.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} settings</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Opening $0 in default browser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Unable to find Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>The following required component was not found on this computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDo you want to download the installer for the component?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>The required component was successfully detected on your computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} will not be able to run.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} will not be able to start because a required component is missing.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Olandese</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russo</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portoghese</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Spagnolo</translation>
    </message>
</context>
</TS>
